@@ -4,9 +4,9 @@
  * Gnome Crystal
  * main.cc 
  *
- * Copyright (C) 2000-2003
+ * Copyright (C) 2000-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,7 +32,11 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <list>
-#include <chemistry/element.h>
+#ifdef GCU_OLD_VER
+#	include <chemistry/element.h>
+#else
+#	include <gcu/element.h>
+#endif
 #include "application.h"
 #include "document.h"
 #include "view.h"
